@@ -1,6 +1,7 @@
 from __future__ import absolute_import as _absolute_import
 
 import _cffi_backend
+
 from pkg_resources import DistributionNotFound as _DistributionNotFound
 from pkg_resources import get_distribution as _get_distribution
 
@@ -21,7 +22,7 @@ def test():
     os.chdir(src_path)
 
     try:
-        return_code = __import__('pytest').main(['-q'])
+        return_code = __import__('pytest').main(['-q', '--doctest-modules'])
     finally:
         os.chdir(old_path)
 
