@@ -50,13 +50,10 @@ Cephes Math Library Release 2.8:  June, 2000
 Copyright 1984, 1987, 1995, 2000 by Stephen L. Moshier
 */
 #include "mconf.h"
-#ifdef ANSIPROT
-extern double incbet ( double, double, double );
-#else
-double incbet();
-#endif
 
-double 
+extern double incbet ( double, double, double );
+
+double
 btdtr (double a, double b, double x)
 {
 
